@@ -6,7 +6,7 @@ from data2code_sdk.plugin.output_data import OutputData
 
 
 @singleton
-class OnConfigLoadSignal(Signal):
+class ConfigLoadedSignal(Signal):
     """
     配置加载完成的信号
     """
@@ -23,7 +23,7 @@ class StartToProcessSignal(Signal):
 
 
 @singleton
-class OnProcessFinishSignal(Signal):
+class ProcessFinishedSignal(Signal):
     """
     (数据）处理完成的信号
     """
@@ -32,7 +32,7 @@ class OnProcessFinishSignal(Signal):
 
 
 @singleton
-class OnAppExitSignal(Signal):
+class AppExitSignal(Signal):
     """
     应用退出时的信号
     """
@@ -40,7 +40,7 @@ class OnAppExitSignal(Signal):
 
 
 @singleton
-class OnAppStartSignal(Signal):
+class AppStartSignal(Signal):
     """
     应用启动时的信号
     """
@@ -48,7 +48,7 @@ class OnAppStartSignal(Signal):
 
 
 @singleton
-class OnLackOfNecessaryPlugin(Signal):
+class LackOfNecessaryPlugin(Signal):
     """
     应用缺少必要插件时的信号
     """
